R/basics.R
assert_not_null.Rd
Assert that an object is not NULL
assert_not_null(x, arg = rlang::caller_arg(x), call = rlang::caller_env())
Object to check.
Name used to refer to x in error messages. Defaults to the name of the expression passed as x.
x
Environment used as the error's call context. Defaults to the calling function, so errors point at the user's code.
The input x, invisibly.
assert_not_null(42)